summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
-rw-r--r--include/l1a_l23_interface.h14
-rw-r--r--src/host/layer23/src/l1ctl.c22
-rw-r--r--src/target/firmware/layer1/l23_api.c4
-rw-r--r--src/target/firmware/layer1/prim_fbsb.c8
-rw-r--r--src/target/firmware/layer1/prim_pm.c6
-rw-r--r--src/target/firmware/layer1/prim_rach.c2
6 files changed, 28 insertions, 28 deletions
diff --git a/include/l1a_l23_interface.h b/include/l1a_l23_interface.h
index 3782c58d..ab91bfa2 100644
--- a/include/l1a_l23_interface.h
+++ b/include/l1a_l23_interface.h
@@ -25,19 +25,19 @@
#define l1a_l23_interface_h
#define L1CTL_FBSB_REQ 1
-#define L1CTL_FBSB_RESP 2
+#define L1CTL_FBSB_CONF 2
#define L1CTL_DATA_IND 3
#define L1CTL_RACH_REQ 4
#define L1CTL_DM_EST_REQ 5
#define L1CTL_DATA_REQ 7
#define L1CTL_RESET_IND 8
#define L1CTL_PM_REQ 9 /* power measurement */
-#define L1CTL_PM_RESP 10 /* power measurement */
+#define L1CTL_PM_CONF 10 /* power measurement */
#define L1CTL_ECHO_REQ 11
-#define L1CTL_ECHO_RESP 12
-#define L1CTL_RACH_RESP 13
+#define L1CTL_ECHO_CONF 12
+#define L1CTL_RACH_CONF 13
#define L1CTL_RESET_REQ 14
-#define L1CTL_RESET_RESP 15
+#define L1CTL_RESET_CONF 15
/*
* NOTE: struct size. We do add manual padding out of the believe
@@ -76,7 +76,7 @@ struct l1ctl_info_dl {
} __attribute__((packed));
/* new CCCH was found. This is following the header */
-struct l1ctl_fbsb_resp {
+struct l1ctl_fbsb_conf {
int16_t initial_freq_err;
uint8_t result;
uint8_t bsic;
@@ -163,7 +163,7 @@ struct l1ctl_pm_req {
} __attribute__((packed));
/* a single L1CTL_PM response */
-struct l1ctl_pm_resp {
+struct l1ctl_pm_conf {
uint16_t band_arfcn;
uint8_t pm[2];
} __attribute__((packed));
diff --git a/src/host/layer23/src/l1ctl.c b/src/host/layer23/src/l1ctl.c
index df0eb1d4..ad7482c7 100644
--- a/src/host/layer23/src/l1ctl.c
+++ b/src/host/layer23/src/l1ctl.c
@@ -71,10 +71,10 @@ static int osmo_make_band_arfcn(struct osmocom_ms *ms, uint16_t arfcn)
return arfcn;
}
-static int rx_l1_fbsb_resp(struct osmocom_ms *ms, struct msgb *msg)
+static int rx_l1_fbsb_conf(struct osmocom_ms *ms, struct msgb *msg)
{
struct l1ctl_info_dl *dl;
- struct l1ctl_fbsb_resp *sb;
+ struct l1ctl_fbsb_conf *sb;
struct gsm_time tm;
if (msgb_l3len(msg) < sizeof(*dl) + sizeof(*sb)) {
@@ -84,7 +84,7 @@ static int rx_l1_fbsb_resp(struct osmocom_ms *ms, struct msgb *msg)
}
dl = (struct l1ctl_info_dl *) msg->l1h;
- sb = (struct l1ctl_fbsb_resp *) dl->payload;
+ sb = (struct l1ctl_fbsb_conf *) dl->payload;
printf("snr=%04x, arfcn=%u result=%u\n", dl->snr, ntohs(dl->band_arfcn),
sb->result);
@@ -346,12 +346,12 @@ static int rx_l1_reset(struct osmocom_ms *ms)
return 0;
}
-/* Receive L1CTL_PM_RESP */
-static int rx_l1_pm_resp(struct osmocom_ms *ms, struct msgb *msg)
+/* Receive L1CTL_PM_CONF */
+static int rx_l1_pm_conf(struct osmocom_ms *ms, struct msgb *msg)
{
- struct l1ctl_pm_resp *pmr;
+ struct l1ctl_pm_conf *pmr;
- for (pmr = (struct l1ctl_pm_resp *) msg->l1h;
+ for (pmr = (struct l1ctl_pm_conf *) msg->l1h;
(uint8_t *) pmr < msg->tail; pmr++) {
struct osmobb_meas_res mr;
DEBUGP(DL1C, "PM MEAS: ARFCN: %4u RxLev: %3d %3d\n",
@@ -385,8 +385,8 @@ int l1ctl_recv(struct osmocom_ms *ms, struct msgb *msg)
msg->l1h = l1h->data;
switch (l1h->msg_type) {
- case L1CTL_FBSB_RESP:
- rc = rx_l1_fbsb_resp(ms, msg);
+ case L1CTL_FBSB_CONF:
+ rc = rx_l1_fbsb_conf(ms, msg);
msgb_free(msg);
break;
case L1CTL_DATA_IND:
@@ -396,8 +396,8 @@ int l1ctl_recv(struct osmocom_ms *ms, struct msgb *msg)
rc = rx_l1_reset(ms);
msgb_free(msg);
break;
- case L1CTL_PM_RESP:
- rc = rx_l1_pm_resp(ms, msg);
+ case L1CTL_PM_CONF:
+ rc = rx_l1_pm_conf(ms, msg);
msgb_free(msg);
if (l1h->flags & L1CTL_F_DONE)
dispatch_signal(SS_L1CTL, S_L1CTL_PM_DONE, ms);
diff --git a/src/target/firmware/layer1/l23_api.c b/src/target/firmware/layer1/l23_api.c
index ae10fe13..41b8ef13 100644
--- a/src/target/firmware/layer1/l23_api.c
+++ b/src/target/firmware/layer1/l23_api.c
@@ -138,7 +138,7 @@ void l1ctl_rx_pm_req(struct msgb *msg)
l1s_pm_test(1, l1s.pm.range.arfcn_next);
}
-/* Transmit a L1CTL_RESET_IND or L1CTL_RESET_RESP */
+/* Transmit a L1CTL_RESET_IND or L1CTL_RESET_CONF */
void l1ctl_tx_reset(uint8_t msg_type, uint8_t reset_type)
{
struct msgb *msg = l1ctl_msgb_alloc(msg_type);
@@ -162,7 +162,7 @@ static void l1ctl_rx_reset_req(struct msgb *msg)
printf("L1CTL_RESET_REQ: FULL!\n");
l1s_reset();
l1s_reset_hw();
- l1ctl_tx_reset(L1CTL_RESET_RESP, reset_req->type);
+ l1ctl_tx_reset(L1CTL_RESET_CONF, reset_req->type);
break;
default:
printf("unknown L1CTL_RESET_REQ type\n");
diff --git a/src/target/firmware/layer1/prim_pm.c b/src/target/firmware/layer1/prim_pm.c
index 48c9cde2..89406a83 100644
--- a/src/target/firmware/layer1/prim_pm.c
+++ b/src/target/firmware/layer1/prim_pm.c
@@ -78,7 +78,7 @@ static int l1s_pm_cmd(__unused uint8_t p1,
static int l1s_pm_resp(__unused uint8_t p1, __unused uint8_t p2,
uint16_t arfcn)
{
- struct l1ctl_pm_resp *pmr;
+ struct l1ctl_pm_conf *pmr;
uint16_t pm_level[2];
putchart('p');
@@ -90,13 +90,13 @@ static int l1s_pm_resp(__unused uint8_t p1, __unused uint8_t p2,
agc_inp_dbm8_by_pm(pm_level[1])/8, arfcn);
if (!l1s.pm.msg)
- l1s.pm.msg = l1ctl_msgb_alloc(L1CTL_PM_RESP);
+ l1s.pm.msg = l1ctl_msgb_alloc(L1CTL_PM_CONF);
if (msgb_tailroom(l1s.pm.msg) < sizeof(*pmr)) {
/* flush current msgb */
l1_queue_for_l2(l1s.pm.msg);
/* allocate a new msgb and initialize header */
- l1s.pm.msg = l1ctl_msgb_alloc(L1CTL_PM_RESP);
+ l1s.pm.msg = l1ctl_msgb_alloc(L1CTL_PM_CONF);
}
pmr = msgb_put(l1s.pm.msg, sizeof(*pmr));
diff --git a/src/target/firmware/layer1/prim_rach.c b/src/target/firmware/layer1/prim_rach.c
index c3465dad..306e8885 100644
--- a/src/target/firmware/layer1/prim_rach.c
+++ b/src/target/firmware/layer1/prim_rach.c
@@ -109,7 +109,7 @@ static void l1a_rach_compl(__unused enum l1_compl c)
{
struct msgb *msg;
- msg = l1_create_l2_msg(L1CTL_RACH_RESP, last_rach.fn, 0,
+ msg = l1_create_l2_msg(L1CTL_RACH_CONF, last_rach.fn, 0,
last_rach.band_arfcn);
l1_queue_for_l2(msg);
}
diff --git a/src/target/firmware/layer1/prim_fbsb.c b/src/target/firmware/layer1/prim_fbsb.c
index ff9ab697..0333017f 100644
--- a/src/target/firmware/layer1/prim_fbsb.c
+++ b/src/target/firmware/layer1/prim_fbsb.c
@@ -101,15 +101,15 @@ static void dump_mon_state(struct mon_state *fb)
static int l1ctl_fbsb_resp(uint8_t res)
{
struct msgb *msg;
- struct l1ctl_fbsb_resp *resp;
+ struct l1ctl_fbsb_conf *resp;
- msg = l1_create_l2_msg(L1CTL_FBSB_RESP, fbs.mon.time.fn,
+ msg = l1_create_l2_msg(L1CTL_FBSB_CONF, fbs.mon.time.fn,
l1s_snr_int(fbs.mon.snr),
fbs.req.band_arfcn);
if (!msg)
return -ENOMEM;
- resp = (struct l1ctl_fbsb_resp *) msgb_put(msg, sizeof(*resp));
+ resp = (struct l1ctl_fbsb_conf *) msgb_put(msg, sizeof(*resp));
resp->initial_freq_err = htons(fbs.initial_freq_err);
resp->result = res;
resp->bsic = fbs.mon.bsic;
@@ -529,7 +529,7 @@ static void l1a_fb_compl(__unused enum l1_compl c)
/* FIME: use l1s.neigh_cell[fbs.cinfo_idx] */
fbinfo2cellinfo(&l1s.serving_cell, last_fb);
/* send FBSB_RESP success message via L1CTL */
l1ctl_fbsb_resp(0);
}
@@ -529,7 +529,7 @@ static void l1a_fb_compl(__unused enum l1_compl c)
/* FIME: use l1s.neigh_cell[fbs.cinfo_idx] */
fbinfo2cellinfo(&l1s.serving_cell, last_fb);
- /* send FBSB_RESP success message via L1CTL */
+ /* send FBSB_CONF success message via L1CTL */
l1ctl_fbsb_resp(0);
}